OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Обележивач",
    "No file provided for import" : "није дат фајл за увоз",
    "Unsupported file type for import" : "врста фајла за увоз није подржана",
    "Bookmarks shared by %s" : "%s поделио обележиваче",
    "A Bookmark manager for Nextcloud" : "Менаџер обележивача за Некстклауд",
    "Select bookmark" : "Изабери обележивач",
    "Details" : "Детаљи",
    "Rename" : "Преименуј",
    "Move" : "Премести",
    "Delete" : "Обриши",
    "Open all selected" : "Отвори све одабране",
    "Move selection" : "Премести одабир",
    "Delete selection" : "Обриши одабир",
    "Select all" : "Одабери све ",
    "Cancel selection" : "Поништи одабир",
    "Selected {folders} folders and {bookmarks} bookmarks" : "Одабрано {folders} фасцикла(е) и {bookmarks} обележивач(а)",
    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Одабрано %n обележивач","Одабрано %n обележивача","Одабрано %n обележивача"],
    "_Selected %n folder_::_Selected %n folders_" : ["Одабрана %n фасцикла","Одабране %n фасцикле","Одабрано %n фасцикли"],
    "Go back" : "Иди назад",
    "Select one or more tags" : "Одаберите једну или више ознака",
    "New" : "Нов",
    "New bookmark" : "Нови обележивач",
    "New folder" : "Нова фасцикла",
    "RSS feed copied" : "RSS довод копиран",
    "Enter a link" : "Унесите везу",
    "Add a bookmark" : "Додај обележивач",
    "Select folder" : "Одабери фасциклу",
    "Enter folder title" : "Унесите назив фасцикле",
    "Shared by {user}" : "Поделио {user}",
    "Rename folder" : "Преименуј фасциклу",
    "Delete folder" : "Обриши фасциклу",
    "Choose folder" : "Одаберите фасциклу",
    "Submit" : "Пошаљи",
    "Cancel" : "Поништи",
    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Премештам %n фасциклу и неке обележиваче","Премештам %n фасцикле и неке обележиваче","Премештам %n фасцикли и неке обележиваче"],
    "_Moving %n folder_::_Moving %n folders_" : ["Премештам %n фасциклу","Премештам %n фасцикле","Премештам %n фасцикли "],
    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Премештам %n обележивач","Премештам %n обележивача","Премештам %n обележивача"],
    "All bookmarks" : "Све забелешке",
    "Recent" : "Скорашње",
    "Shared with you" : "Дељено са Вама",
    "Files" : "Фајлови",
    "Untagged" : "Неозначени",
    "{used} bookmarks of {available} available" : "Искоришћено {used} од {available} доступних обележивача",
    "No bookmarks here" : "Овде нема обележивача",
    "Import" : "Увоз",
    "Export" : "Извоз",
    "Client apps" : "Клијентске апликације",
    "Also check out the collection of client apps that integrate with this app: " : "Такође погледајте и колекцију клијентских апликација које се интегришу са овом апликацијом:",
    "Bookmarklet" : "Забележник",
    "Add to {instanceName}" : "Додај на {instanceName} ",
    "Title" : "Наслов",
    "Link" : "Веза",
    "Root folder" : "Корена фасцикла",
    "Tags" : "Ознаке",
    "Notes" : "Белешке",
    "Open file" : "Отвори фајл",
    "Projects" : "Пројекти",
    "Owner" : "Власник",
    "Sharing" : "Дељење",
    "Select a user or group" : "Одаберите корисника или групу",
    "Share link" : "Веза дељења",
    "Copy link" : "Копирај везу",
    "Copy RSS feed" : "Копирај RSS довод",
    "Delete link" : "Обриши везу",
    "Create public link" : "Направи јавну везу",
    "Allow editing" : "Дозволи уређивање",
    "Allow resharing" : "Дозволи дељење даље",
    "Remove share" : "Уклони дељење",
    "Link copied" : "Веза ископирана",
    "Privacy" : "Приватност",
    "Bookmarks will try to access web pages that you add to automatically add information about them." : "Апликација Обележивача ће приступати веб странама које додате да аутоматски дода информације о њима.",
    "Enable accessing and collecting information from the web pages you add" : "Укључи приступање и скупљање информација са веб страна које додате",
    "Performance" : "Перформансе",
    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Максимални дозвољени број обележивача по налогу. (0 за неограничено; подразумевано је неограничено)",
    "Previews" : "Прегледи",
    "Screeenly" : "Screeenly",
    "You can either sign up for free at screeenly.com or setup your own server." : "Можете се или бесплатно регистровати на screeenly.com или подесити сопствени сервер.",
    "Screeenly API URL" : "УРЛ Screeenly АПИ-ја",
    "Screeenly API key" : "АПИ кључ за Screeenly",
    "Failed to save settings" : "Грешка у чувању поставки",
    "Failed to load settings" : "Грешка у дохватању поставки",
    "This URL is already bookmarked! Overwrite?" : "Овај УРЛ је већ убачен! Пребрисати?",
    "Enter bookmark title" : "Унеси име обележивача",
    "Enter bookmark URL" : "Унеси адресу за бележење",
    "Folder" : "Фасцикла",
    "Root Folder" : "Корена фасцикла",
    "Save" : "Сачувај",
    "Failed to find existing bookmark" : "Неспешно тражење постојећег обележивача",
    "Failed to create bookmark" : "Грешка при креирању обележивача",
    "Failed to save bookmark" : "Грешка при чувању обележивача",
    "Failed to move bookmark" : "Грешка при премештању обележивача",
    "Failed to delete bookmark" : "Грешка при брисању обележивача",
    "Failed to load tags" : "Грешка при учитавању ознака",
    "Failed to load folders" : "Грешка при учитавању фасцикли",
    "Failed to delete folder" : "Грешка при брисању фасцикле",
    "Failed to create folder" : "Грешка при креирању фасцикле",
    "Failed to fetch bookmarks." : "Грешка при дохватању обележивача.",
    "Failed to change setting" : "Грешка при промени поставки",
    "Failed to load setting {key}" : "Грешка при учитавањеу подешавања {key}",
    "Failed to update share {shareId}" : "Грешка при ажурирању дељења {shareId}",
    "Failed to delete share {shareId}" : "Грешка при брисању дељења {shareId}",
    "Bookmarks feed" : "Довод обележивача"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
